==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/Sc55a5931493a077466f7844539048aed.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 class Sa374ae40bab87d51f64df15ce1e0bd84; class S7a8c30ba69067011071ba14cc1b4a63d; void S6a2be9550c2fb0fca07a642ab038eb1c(void); 
void Sa1e4fb5a02505379760395fadfe51275(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &Sd304ba20e96d87411588eeabac850e34, double S2ffe4e77325d9a7152f7086ea7aa5114); 
void S7a731efa3a782d179bcee5ec71a64bfd(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
double S2063c1608d6e0baf80249c42e2be5804); void Sda3964cebceff4d319db205e954635dc(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S194e81b29fd28d88010d968660bd0f57(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S51079f5441d302bbc9b5337dd6ec5a64); void S12eccebf42309b081e3c175c6ddb59e2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, Sa374ae40bab87d51f64df15ce1e0bd84 *S246067a0102d64c9a5304375b7e01862, 
Se812b5a98988bad1d5b8df118cb6cc7f *Scd57a838aa3a06e3afcc54e1592168eb, double S2063c1608d6e0baf80249c42e2be5804, 
bool S7cf74ca49c304df8150205fc915cd465, bool S224d14a7ce73f78617dcdc4f9e03afe7, bool S2b513fd5243d579de0877fc4d394aa97); 
void S8d3ca5a4783179ee51eaab1feb7b23f6(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sd5d3db1765287eef77d7927cc956f50a); void S105ddaad09dee868c10adfc0636fe048(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S884a3497db076d8f1999d24ba47199b5(Sa374ae40bab87d51f64df15ce1e0bd84 
*S1d8d5e912302108b5e88c3e77fcad378, S7a8c30ba69067011071ba14cc1b4a63d *S95cc64dd2825f9df13ec4ad683ecf339); 
void S774ed7db640aa5cb76dde19ad4d6ec9b(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sbd42b50e418bb981631ad92d0aae607d(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sb2733effb00d081f7f4e0b908d2c38a1(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S4f111e747034043a5ae1abb973115229(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S539eaec1b246056c662194800c9dac7b(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
unsigned long Sb80bb7740288fda1f201890375a60c8f); void S16c152dd44413a241ca9004b8e91d32a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Scb5e100e5a9a3e7f6d1fd97512215282); unsigned long S83b01aeec9233afc50404f7399e57805(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void Sc50f9528c97bafa7784a3af7bd01d2aa(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179);

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/Sc55a5931493a077466f7844539048aed.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 class Sa374ae40bab87d51f64df15ce1e0bd84; class S7a8c30ba69067011071ba14cc1b4a63d; void S6a2be9550c2fb0fca07a642ab038eb1c(void); 
void Sa1e4fb5a02505379760395fadfe51275(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &Sd304ba20e96d87411588eeabac850e34, double S2ffe4e77325d9a7152f7086ea7aa5114); 
void S7a731efa3a782d179bcee5ec71a64bfd(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
double S2063c1608d6e0baf80249c42e2be5804); void Sda3964cebceff4d319db205e954635dc(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void Saf9b3371d4dfd9f9d49c0713987ff511(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S51079f5441d302bbc9b5337dd6ec5a64); void Saf9b3371d4dfd9f9d49c0713987ff511(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S51079f5441d302bbc9b5337dd6ec5a64, bool Sbc7d420606e2e2ab63b4a2528a7bbadf); 
void S12eccebf42309b081e3c175c6ddb59e2(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
Sa374ae40bab87d51f64df15ce1e0bd84 *S246067a0102d64c9a5304375b7e01862, Se812b5a98988bad1d5b8df118cb6cc7f 
*Scd57a838aa3a06e3afcc54e1592168eb, double S2063c1608d6e0baf80249c42e2be5804, bool S7cf74ca49c304df8150205fc915cd465, 
bool S224d14a7ce73f78617dcdc4f9e03afe7, bool S2b513fd5243d579de0877fc4d394aa97); void S8d3ca5a4783179ee51eaab1feb7b23f6(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Sd5d3db1765287eef77d7927cc956f50a); void S105ddaad09dee868c10adfc0636fe048(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S884a3497db076d8f1999d24ba47199b5(Sa374ae40bab87d51f64df15ce1e0bd84 
*S1d8d5e912302108b5e88c3e77fcad378, S7a8c30ba69067011071ba14cc1b4a63d *S95cc64dd2825f9df13ec4ad683ecf339); 
void S774ed7db640aa5cb76dde19ad4d6ec9b(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sbd42b50e418bb981631ad92d0aae607d(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sb2733effb00d081f7f4e0b908d2c38a1(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S4f111e747034043a5ae1abb973115229(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S539eaec1b246056c662194800c9dac7b(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
unsigned long Sb80bb7740288fda1f201890375a60c8f); void S16c152dd44413a241ca9004b8e91d32a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *Scb5e100e5a9a3e7f6d1fd97512215282); unsigned long S83b01aeec9233afc50404f7399e57805(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void Sc50f9528c97bafa7784a3af7bd01d2aa(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179);
